==> jmx_prometheus_javaagent-0.17.0-sources.jar: io/prometheus/jmx/shaded/org/yaml/snakeyaml/resolver/ResolverTuple.java <==
/**
 * io.prometheus.jmx.shaded.Copyrightio.prometheus.jmx.shaded. (io.prometheus.jmx.shaded.cio.prometheus.jmx.shaded.) io.prometheus.jmx.shaded.2008io.prometheus.jmx.shaded., io.prometheus.jmx.shaded.SnakeYAMLio.prometheus.jmx.shaded.
 *
 * io.prometheus.jmx.shaded.Licensedio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.underio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Apacheio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded., io.prometheus.jmx.shaded.Versionio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.2io.prometheus.jmx.shaded..io.prometheus.jmx.shaded.0io.prometheus.jmx.shaded. (io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. "io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded.");
 * io.prometheus.jmx.shaded.youio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.mayio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.notio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.useio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.thisio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.fileio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.exceptio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.inio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.complianceio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.withio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded..
 * io.prometheus.jmx.shaded.Youio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.mayio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.obtainio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.aio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.copyio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ofio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.atio.prometheus.jmx.shaded.
 *
 *     io.prometheus.jmx.shaded.httpio.prometheus.jmx.shaded.://io.prometheus.jmx.shaded.wwwio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.apacheio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.orgio.prometheus.jmx.shaded./io.prometheus.jmx.shaded.licensesio.prometheus.jmx.shaded./io.prometheus.jmx.shaded.LICENSEio.prometheus.jmx.shaded.-io.prometheus.jmx.shaded.2io.prometheus.jmx.shaded..io.prometheus.jmx.shaded.0io.prometheus.jmx.shaded.
 *
 * io.prometheus.jmx.shaded.Unlessio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.requiredio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.byio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.applicableio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.lawio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.orio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.agreedio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.toio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.inio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.writingio.prometheus.jmx.shaded., io.prometheus.jmx.shaded.softwareio.prometheus.jmx.shaded.
 * io.prometheus.jmx.shaded.distributedio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.underio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.isio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.distributedio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.onio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.anio.prometheus.jmx.shaded. "io.prometheus.jmx.shaded.ASio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ISio.prometheus.jmx.shaded." io.prometheus.jmx.shaded.BASISio.prometheus.jmx.shaded.,
 * io.prometheus.jmx.shaded.WITHOUTio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.WARRANTIESio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ORio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.CONDITIONSio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.OFio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ANYio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.KINDio.prometheus.jmx.shaded., io.prometheus.jmx.shaded.eitherio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.expressio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.orio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.impliedio.prometheus.jmx.shaded..
 * io.prometheus.jmx.shaded.Seeio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.forio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.specificio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.languageio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.governingio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.permissionsio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.andio.prometheus.jmx.shaded.
 * io.prometheus.jmx.shaded.limitationsio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.underio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded..
 */
io.prometheus.jmx.shaded.packageio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.orgio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.yamlio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.snakeyamlio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.resolverio.prometheus.jmx.shaded.;

io.prometheus.jmx.shaded.importio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.javaio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.utilio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.regexio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.Patternio.prometheus.jmx.shaded.;

io.prometheus.jmx.shaded.importio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.orgio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.yamlio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.snakeyamlio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.nodesio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.Tagio.prometheus.jmx.shaded.;

io.prometheus.jmx.shaded.finalio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.classio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ResolverTupleio.prometheus.jmx.shaded. {
    io.prometheus.jmx.shaded.privateio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.finalio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Tagio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded.;
    io.prometheus.jmx.shaded.privateio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.finalio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Patternio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.;

    io.prometheus.jmx.shaded.publicio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ResolverTupleio.prometheus.jmx.shaded.(io.prometheus.jmx.shaded.Tagio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded., io.prometheus.jmx.shaded.Patternio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.) {
        io.prometheus.jmx.shaded.thisio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded. = io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded.;
        io.prometheus.jmx.shaded.thisio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded. = io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.;
    }

    io.prometheus.jmx.shaded.publicio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Tagio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.getTagio.prometheus.jmx.shaded.() {
        io.prometheus.jmx.shaded.returnio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded.;
    }

    io.prometheus.jmx.shaded.publicio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Patternio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.getRegexpio.prometheus.jmx.shaded.() {
        io.prometheus.jmx.shaded.returnio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.;
    }

    @io.prometheus.jmx.shaded.Overrideio.prometheus.jmx.shaded.
    io.prometheus.jmx.shaded.publicio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Stringio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.toStringio.prometheus.jmx.shaded.() {
        io.prometheus.jmx.shaded.returnio.prometheus.jmx.shaded. "io.prometheus.jmx.shaded.Tupleio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded.=" + io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded. + " io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.=" + io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.;
    }
}

==> jmx_prometheus_javaagent-0.17.1-sources.jar: io/prometheus/jmx/shaded/org/yaml/snakeyaml/resolver/ResolverTuple.java <==
/**
 * io.prometheus.jmx.shaded.Copyrightio.prometheus.jmx.shaded. (io.prometheus.jmx.shaded.cio.prometheus.jmx.shaded.) io.prometheus.jmx.shaded.2008io.prometheus.jmx.shaded., io.prometheus.jmx.shaded.SnakeYAMLio.prometheus.jmx.shaded.
 *
 * io.prometheus.jmx.shaded.Licensedio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.underio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Apacheio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded., io.prometheus.jmx.shaded.Versionio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.2io.prometheus.jmx.shaded..io.prometheus.jmx.shaded.0io.prometheus.jmx.shaded. (io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. "io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded.");
 * io.prometheus.jmx.shaded.youio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.mayio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.notio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.useio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.thisio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.fileio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.exceptio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.inio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.complianceio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.withio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded..
 * io.prometheus.jmx.shaded.Youio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.mayio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.obtainio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.aio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.copyio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ofio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.atio.prometheus.jmx.shaded.
 *
 *     io.prometheus.jmx.shaded.httpio.prometheus.jmx.shaded.://io.prometheus.jmx.shaded.wwwio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.apacheio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.orgio.prometheus.jmx.shaded./io.prometheus.jmx.shaded.licensesio.prometheus.jmx.shaded./io.prometheus.jmx.shaded.LICENSEio.prometheus.jmx.shaded.-io.prometheus.jmx.shaded.2io.prometheus.jmx.shaded..io.prometheus.jmx.shaded.0io.prometheus.jmx.shaded.
 *
 * io.prometheus.jmx.shaded.Unlessio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.requiredio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.byio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.applicableio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.lawio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.orio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.agreedio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.toio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.inio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.writingio.prometheus.jmx.shaded., io.prometheus.jmx.shaded.softwareio.prometheus.jmx.shaded.
 * io.prometheus.jmx.shaded.distributedio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.underio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.isio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.distributedio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.onio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.anio.prometheus.jmx.shaded. "io.prometheus.jmx.shaded.ASio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ISio.prometheus.jmx.shaded." io.prometheus.jmx.shaded.BASISio.prometheus.jmx.shaded.,
 * io.prometheus.jmx.shaded.WITHOUTio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.WARRANTIESio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ORio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.CONDITIONSio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.OFio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ANYio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.KINDio.prometheus.jmx.shaded., io.prometheus.jmx.shaded.eitherio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.expressio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.orio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.impliedio.prometheus.jmx.shaded..
 * io.prometheus.jmx.shaded.Seeio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.forio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.specificio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.languageio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.governingio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.permissionsio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.andio.prometheus.jmx.shaded.
 * io.prometheus.jmx.shaded.limitationsio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.underio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.theio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Licenseio.prometheus.jmx.shaded..
 */
io.prometheus.jmx.shaded.packageio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.orgio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.yamlio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.snakeyamlio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.resolverio.prometheus.jmx.shaded.;

io.prometheus.jmx.shaded.importio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.javaio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.utilio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.regexio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.Patternio.prometheus.jmx.shaded.;
io.prometheus.jmx.shaded.importio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.orgio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.yamlio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.snakeyamlio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.nodesio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.Tagio.prometheus.jmx.shaded.;

io.prometheus.jmx.shaded.finalio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.classio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ResolverTupleio.prometheus.jmx.shaded. {

  io.prometheus.jmx.shaded.privateio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.finalio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Tagio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded.;
  io.prometheus.jmx.shaded.privateio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.finalio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Patternio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.;
  io.prometheus.jmx.shaded.privateio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.finalio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.intio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.limitio.prometheus.jmx.shaded.;

  io.prometheus.jmx.shaded.publicio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.ResolverTupleio.prometheus.jmx.shaded.(io.prometheus.jmx.shaded.Tagio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded., io.prometheus.jmx.shaded.Patternio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded., io.prometheus.jmx.shaded.intio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.limitio.prometheus.jmx.shaded.) {
    io.prometheus.jmx.shaded.thisio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded. = io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded.;
    io.prometheus.jmx.shaded.thisio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded. = io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.;
    io.prometheus.jmx.shaded.thisio.prometheus.jmx.shaded..io.prometheus.jmx.shaded.limitio.prometheus.jmx.shaded. = io.prometheus.jmx.shaded.limitio.prometheus.jmx.shaded.;
  }

  io.prometheus.jmx.shaded.publicio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Tagio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.getTagio.prometheus.jmx.shaded.() {
    io.prometheus.jmx.shaded.returnio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded.;
  }

  io.prometheus.jmx.shaded.publicio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Patternio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.getRegexpio.prometheus.jmx.shaded.() {
    io.prometheus.jmx.shaded.returnio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.;
  }

  io.prometheus.jmx.shaded.publicio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.intio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.getLimitio.prometheus.jmx.shaded.() {
    io.prometheus.jmx.shaded.returnio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.limitio.prometheus.jmx.shaded.;
  }

  @io.prometheus.jmx.shaded.Overrideio.prometheus.jmx.shaded.
  io.prometheus.jmx.shaded.publicio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.Stringio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.toStringio.prometheus.jmx.shaded.() {
    io.prometheus.jmx.shaded.returnio.prometheus.jmx.shaded. "io.prometheus.jmx.shaded.Tupleio.prometheus.jmx.shaded. io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded.=" + io.prometheus.jmx.shaded.tagio.prometheus.jmx.shaded. + " io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded.=" + io.prometheus.jmx.shaded.regexpio.prometheus.jmx.shaded. + " io.prometheus.jmx.shaded.limitio.prometheus.jmx.shaded.=" + io.prometheus.jmx.shaded.limitio.prometheus.jmx.shaded.;
  }
}
